// HLDemo.java

import java.awt.*;
import java.awt.event.*;

import javax.swing.*;
import javax.swing.border.*;

import org.jdesktop.swingx.JXHyperlink;

public class HLDemo
{
   public static void main (String [] args)
   {
      // Establish a look and feel for this application's about dialog box.

      setLookAndFeel ();

      // Construct a modal about dialog box with a title, a message, and link
      // information.

      AboutDialog ad = new AboutDialog (null,
                                        "HLDemo",
                                        "HLDemo 1.0",
                                        "by Jeff Friesen",
                                        "http://www.javajeff.mb.ca");

      // Present the about dialog box to the user. Because the about dialog box 
      // is modal, the thread executing the main() method will not exit this 
      // method until the dialog box is disposed.

      ad.setVisible (true);
   }

   static void setLookAndFeel ()
   {
      try
      {
          // Return the name of the LookAndFeel class that implements the
          // native OS look and feel. If there is no such look and feel, return 
          // the name of the default cross platform LookAndFeel class.

          String slafcn = UIManager.getSystemLookAndFeelClassName ();

          // Set the current look and feel to the look and feel identified by
          // the LookAndFeel class name.

          UIManager.setLookAndFeel (slafcn);
      }
      catch(Exception e)
      {
      }
   }
}

class AboutDialog extends JDialog
{
   AboutDialog (JFrame parent, String title, String message, String linkText,
                String link)
   {
      // Assign title to the dialog box's title bar and make sure dialog box is 
      // modal.

      super (parent, title, true);

      // Tell dialog box to automatically hide and dispose itself when the user 
      // selects the Close menu item from the dialog box's system menu.

      setDefaultCloseOperation (DISPOSE_ON_CLOSE);

      // Establish the dialog box's border area. A compound border establishes
      // a beveled outer border with an empty inner border, which is used as a
      // margin.

      Border border = BorderFactory.createBevelBorder (BevelBorder.LOWERED);
      Border margin = BorderFactory.createEmptyBorder (10, 10, 10, 10);
      Border cborder = BorderFactory.createCompoundBorder (border, margin);
      getRootPane ().setBorder (cborder);

      // Use a vertical Box as the dialog box's content pane, to simplify
      // layout.

      Box box = Box.createVerticalBox ();
      setContentPane (box);

      // Add a message (typically identifying the program) label to the box's
      // top. This label is horizontally centered within the box.

      JLabel label = new JLabel (message);
      label.setAlignmentX (0.5f);
      box.add (label);

      // Add a 30-pixel vertical blank space below the message label to the box 
      // (for aesthetic purposes).

      box.add (Box.createVerticalStrut (30));

      // Add a hyperlink to the box's middle. This hyperlink is horizontally
      // centered within the box.

      JXHyperlink hyperlink;
      hyperlink = new JXHyperlink (new LinkAction (linkText, link));
      hyperlink.setAlignmentX (0.5f);
      box.add (hyperlink);

      // Add a 30-pixel vertical blank space below the hyperlink to the box
      // (for aesthetic purposes).

      box.add (Box.createVerticalStrut (30));

      // Add an OK button to the box's bottom. This button is horizontally
      // centered within the box. Assign an action listener to hide and dispose 
      // the dialog box (when the button is clicked).

      JButton button = new JButton ("OK");
      button.setAlignmentX (0.5f);
      button.addActionListener (new ActionListener ()
                                {
                                    public void actionPerformed (ActionEvent e)
                                    {
                                       dispose ();
                                    }
                                });
      box.add (button);

      // Size dialog box to fit the preferred size and layouts of its 
      // components.

      pack ();

      // Center the dialog box (when displayed) relative to its parent window.
      // If the parent window is not showing, the dialog box is centered on the 
      // screen.

      setLocationRelativeTo (parent);

      // Give input focus to the button.

      button.requestFocusInWindow ();
   }

   private class LinkAction extends AbstractAction
   {
      LinkAction (String linkText, String link)
      {
         // Save the link's text and the actual link for later recall when the
         // user clicks the hyperlink.

         putValue (Action.NAME, linkText);
         putValue (Action.SHORT_DESCRIPTION, link);
      }

      public void actionPerformed (ActionEvent e)
      {
         // Retrieve the actual link and output link to the console (for test
         // purposes).

         String link = (String) getValue (Action.SHORT_DESCRIPTION);
         System.out.println (link);

         // Launch the default Web browser and have the Web browser display the 
         // Web page associated with the link.

         BareBonesBrowserLaunch.openURL (link);
      }
   }
}
