// MoreSwingX2.java

// Demonstrate JXTable highlighter pipeline with alternate row highlighter.

import javax.swing.*;
import javax.swing.table.*;

import org.jdesktop.swingx.JXTable;
import org.jdesktop.swingx.decorator.*;

class MoreSwingX2 extends JFrame
{
   MoreSwingX2 (String title)
   {
      // Assign title to the frame window's title bar.

      super (title);

      // Tell application to automatically exit when the user selects the Close
      // menu item from the frame window's system menu.

      setDefaultCloseOperation (EXIT_ON_CLOSE);

      // Create a default table model consisting of 12 rows by 2 columns.

      DefaultTableModel dtm = new DefaultTableModel (12, 2);

      // Assign column identifiers (headers) to the columns.

      String [] columnTitles =
      {
         "Month",
         "Days",
      };

      dtm.setColumnIdentifiers (columnTitles);

      // Populate all cells in the default table model.

      String [] months =
      {
         "January",
         "February",
         "March",
         "April",
         "May",
         "June",
         "July",
         "August",
         "September",
         "October",
         "November",
         "December"
      };

      String [] days =
      {
         "31",
         "28 (29 on leap year)",
         "31",
         "30",
         "31",
         "30",
         "31",
         "31",
         "30",
         "31",
         "30",
         "31"
      };

      int nrows = dtm.getRowCount ();
      int ncols = dtm.getColumnCount ();

      for (int i = 0; i < nrows; i++)
      {
           dtm.setValueAt (months [i], i, 0);
           dtm.setValueAt (days [i], i, 1);
      }

      // Create a table using the previously-created default table model.

      JXTable table = new JXTable (dtm);

      // Create a highlighter pipeline that applies various changes to a
      // JXTable in a resusable and pluggable fashion. Add a single alternate
      // row highlighter, which prepares a cell renderer to use different
      // background colors for alternating rows in a data view, to the 
      // pipeline. Attach the pipeline to the JXTable.

      HighlighterPipeline highlighters = new HighlighterPipeline ();
      highlighters.addHighlighter (new AlternateRowHighlighter ());
      table.setHighlighters (highlighters);

      // Place the table in a JScrollPane object (to allow the table to be
      // vertically scrolled and display scrollbars, as necessary).

      JScrollPane jsp = new JScrollPane (table);

      // Fill entire GUI with jscrollpane.

      getContentPane ().add (jsp);

      // Size the GUI to reveal the complete contents of the title bar.

      setSize (350, 250);

      // Display GUI and start the AWT's event-dispatching thread.

      setVisible (true);
   }

   public static void main (String [] args)
   {
      new MoreSwingX2 ("SwingX JXTable Row-highlighting Demo");
   }
}
