// TOTDDemo.java

import java.awt.*;
import java.awt.event.*;

import java.io.*;

import java.util.*;

import javax.swing.*;

import org.jdesktop.swingx.JXTipOfTheDay;
import org.jdesktop.swingx.tips.*;

public class TOTDDemo
{
   public static void main (String [] args)
   {
      // Create a frame window whose GUI lets us choose various demonstrations.

      final JFrame frame = new JFrame ("Tip Of The Day Demo");

      // Tell application to automatically exit when the user selects the Close
      // menu item from the frame window's system menu.

      frame.setDefaultCloseOperation (JFrame.EXIT_ON_CLOSE);

      // Create a panel, divided into a 2x2 grid for, storing launch buttons.

      JPanel panel = new JPanel ();
      panel.setLayout (new GridLayout (2, 2));

      // Create a button to launch first demonstration: basic use of "Tip of 
      // the Day" dialog box.

      JButton button = new JButton ("Demo #1");
      button.addActionListener (new ActionListener ()
                                {
                                    public void actionPerformed (ActionEvent e)
                                    {
                                       demo1 (frame);
                                    }
                                });
      panel.add (button);

      // Create a button to launch second demonstration: loading tips from a
      // properties file.

      button = new JButton ("Demo #2");
      button.addActionListener (new ActionListener ()
                                {
                                    public void actionPerformed (ActionEvent e)
                                    {
                                       demo2 (frame);
                                    }
                                });
      panel.add (button);

      // Create a button to launch third demonstration: giving user the ability
      // to prevent future activation of dialog box.

      button = new JButton ("Demo #3");
      button.addActionListener (new ActionListener ()
                                {
                                    public void actionPerformed (ActionEvent e)
                                    {
                                       demo3 (frame);
                                    }
                                });
      panel.add (button);

      // Create a button to launch fourth demonstration: choosing a different
      // tip for each startup.

      button = new JButton ("Demo #4");
      button.addActionListener (new ActionListener ()
                                {
                                    public void actionPerformed (ActionEvent e)
                                    {
                                       demo4 (frame);
                                    }
                                });
      panel.add (button);

      frame.getContentPane ().add (panel);

      // Size the GUI to reveal the complete contents of the title bar.

      frame.setSize (250, 100);

      // Display GUI and start the AWT's event-dispatching thread.

      frame.setVisible (true);
   }

   static void demo1 (JFrame frame)
   {
      TipOfTheDayModel.Tip tip1;
      tip1 = new DefaultTip ("Tip 1",
                             "<html>You can <strong>embed</strong> various " +
                             "<em>HTML</em> tags in tips.");

      TipOfTheDayModel.Tip tip2;
      tip2 = new DefaultTip ("Tip 2",
                             "JXTipOfTheDay provides methods that let you " +
                             "programmatically navigate tips when you use " +
                             "JXTipOfTheDay as a pane.");

      java.util.List<TipOfTheDayModel.Tip> tips =
        java.util.Arrays.asList (tip1, tip2);
      DefaultTipOfTheDayModel model = new DefaultTipOfTheDayModel (tips);

      JXTipOfTheDay totd = new JXTipOfTheDay (model);

      totd.showDialog (frame);
   }

   static void demo2 (JFrame frame)
   {
      Properties tips = new Properties ();

      FileInputStream fis = null;

      try
      {
          fis = new FileInputStream ("tips.properties");

          tips.load (fis);
 
          TipOfTheDayModel model = TipLoader.load (tips);

          JXTipOfTheDay totd = new JXTipOfTheDay (model);
 
          totd.showDialog (frame);
      }
      catch (IOException e)
      {
          JOptionPane.showMessageDialog (frame, e.getMessage ());
      }
   }

   static void demo3 (JFrame frame)
   {
      TipOfTheDayModel.Tip tip1;
      tip1 = new DefaultTip ("Tip 1",
                             "<html>You can <strong>embed</strong> various " +
                             "<em>HTML</em> tags in tips.");

      TipOfTheDayModel.Tip tip2;
      tip2 = new DefaultTip ("Tip 2",
                             "JXTipOfTheDay provides methods that let you " +
                             "programmatically navigate tips when you use " +
                             "JXTipOfTheDay as a pane.");

      java.util.List<TipOfTheDayModel.Tip> tips =
        java.util.Arrays.asList (tip1, tip2);
      DefaultTipOfTheDayModel model = new DefaultTipOfTheDayModel (tips);

      JXTipOfTheDay totd = new JXTipOfTheDay (model);

      totd.showDialog (frame, new JXTipOfTheDay.ShowOnStartupChoice ()
                              {
                                  public boolean isShowingOnStartup ()
                                  {
                                     // Obtain value from persistent storage.
                                     // Here we assume that we always want to
                                     // show tips at startup.

                                     return true;
                                  }

                                  public void setShowingOnStartup (boolean x)
                                  {
                                     // Save user choice value to persistent
                                     // storage. Here we just output the value
                                     // for simplicity.

                                     if (x)
                                         System.out.println ("User wants tips");
                                     else
                                         System.out.println ("No tips");
                                  }
                              });
   }

   static void demo4 (JFrame frame)
   {
      TipOfTheDayModel.Tip tip1;
      tip1 = new DefaultTip ("Tip 1",
                             "<html>You can <strong>embed</strong> various " +
                             "<em>HTML</em> tags in tips.");

      TipOfTheDayModel.Tip tip2;
      tip2 = new DefaultTip ("Tip 2",
                             "JXTipOfTheDay provides methods that let you " +
                             "programmatically navigate tips when you use " +
                             "JXTipOfTheDay as a pane.");

      java.util.List<TipOfTheDayModel.Tip> tips =
        java.util.Arrays.asList (tip1, tip2);
      DefaultTipOfTheDayModel model = new DefaultTipOfTheDayModel (tips);

      final JXTipOfTheDay totd = new JXTipOfTheDay (model);
      totd.setCurrentTip (0); // Assume value read from persistent storage.

      totd.showDialog (frame, new JXTipOfTheDay.ShowOnStartupChoice ()
                              {
                                  public boolean isShowingOnStartup ()
                                  {
                                     // Obtain value from persistent storage.
                                     // Here we assume that we always want to
                                     // show tips at startup.

                                     return true;
                                  }

                                  public void setShowingOnStartup (boolean x)
                                  {
                                     // Save user choice value to persistent
                                     // storage. Here we just output the value
                                     // for simplicity.

                                     if (x)
                                         System.out.println ("User wants tips");
                                     else
                                         System.out.println ("No tips");

                                     // Presumably, we also save the index of 
                                     // the next tip to display at startup.
                                     // Here we just output this index.

                                     int ct = totd.getCurrentTip ();

                                     int nt = totd.getModel ().getTipCount ();

                                     if (++ct == nt)
                                         ct = 0;

                                     System.out.println ("Future tip is " + ct);
                                  }
                              });
   }
}
